// @ts-check

/** @type {import('./types/options').GetComponentName} */
// By default we prefix all of our components with a 'C'. A prefix is not needed in 99% of all cases but there are some situations which require a prefix. One edge case is the 'Link' component. 'Link' is considered by some players in the Vue ecosystem to be an invalid component name. For example having the following component:

/*
<template>
  <CLink>hi</CLink>
</template>
*/
// Will make eslint complain ('The template root requires an element rather than texts' and 'Parsing error: x-invalid-end-tag'). Because of that we simply prefix all of our components with a 'C'.
const defaultComponentName = context => `C${context.name}`;

// @ts-check
/** @returns {import('./types/options')._Options} */

var createDefaultOptions = (() => ({
  onDidRegisterComponent: () => {},
  componentName: defaultComponentName
}));

// @ts-check
var normalizedPluginOptions = ((options = createDefaultOptions()) => {
  return { ...createDefaultOptions(),
    ...options
  };
});

// @ts-check

const getComponentName = component => {
  if (typeof component === 'function') {
    const {
      prototype
    } = component;
    return prototype.constructor.extendOptions.name;
  }

  return component.name;
}; // This function turns any constructor into a Vue plugin.
// If you have a components that depends on other components to be globally
// installed pass them as the seoncond parameter.

/** @param {Array<import('vue').Component>} dependencies */


var index = ((...dependencies) => {
  const install = (vue, options) => {
    const _options = normalizedPluginOptions(options);

    const {
      onDidRegisterComponent
    } = _options;
    dependencies.forEach(component => {
      const rawComponentName = getComponentName(component);

      if (rawComponentName == null) {
        throw new Error(`
            Unable to determine component name. Component: ${component}. Did you forget to add a 'name' attribute?
                `);
      }

      const componentName = _options.componentName({
        name: rawComponentName,
        component: component
      });

      vue.component(componentName, component);
      onDidRegisterComponent({
        component,
        name: componentName
      });
    });
  };

  function createMixin(options) {
    const _options = normalizedPluginOptions(options);

    const componentsOption = {};
    dependencies.forEach(component => {
      const rawComponentName = getComponentName(component);

      if (rawComponentName == null) {
        throw new Error(`
            Unable to determine component name. Component: ${component}. Did you forget to add a 'name' attribute?
                `);
      }

      const componentName = _options.componentName({
        name: rawComponentName,
        component: component
      });

      componentsOption[componentName] = component;
    });
    return {
      components: componentsOption
    };
  }

  createMixin.install = install;
  return createMixin;
});

export default index;
//# sourceMappingURL=index.esm.js.map
